==> homesitemaker-v0.4.1.tar.gz: homesitemaker/includes/languages/catalan/homesite-news.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004 Marcos Martinez Jimenez

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

//---------- ./homesite/info.php ----------

// Headline Row (HR)
$TEXT001="Enviar";
$TEXT002="Publicat el";
$TEXT003="per";
$TEXT004="Editat per &uacute;ltima vegada";

$TEXT005="Secci&oacute; vuida !<br>".
         "Potser vulguis afegir alguna informaci&oacute; aqu&iacute;.<br>".
         "Si no, hauries d'esborrar aquesta secci&oacute;.";

$TEXT006="Comentaris";
$TEXT007="Enviar comentari";
$TEXT008="Editar";
$TEXT009="Esborrar";
$TEXT010="Anterior";
$TEXT011="Seg&uulm;ent";
$TEXT012="Total";
$TEXT013="Data d'Edici&oacute;";
$TEXT014="Autor";
$TEXT015="Titular";
$TEXT048="Text Introductori";
$TEXT016="Text";
$TEXT049="Si est&agraves editant una not&iacute;cia molt llarga, quedar&agrave; millor si la divideixes en duess parts.<br>".
         "Utilitza el quadre d'edici&oacute; \"$TEXT048\" per introduir-la i el quadre \"$TEXT016\" per la resta.";
$TEXT017="Si env&iacute;es com HTML, llavors les etiquetes ser&agrave;n interpretades";
$TEXT045="Enviar com:";
$TEXT046="Text pla";
$TEXT047="HTML";

$TEXT018="Aquesta es la llista amb les fotos que hi ha actualment per a aquesta not&iacute;cia.<br>".
         "Pots seleccionar aquelles que vulguis esborrar<br>".
         "Si pel contrari vols afegir un altre imatge a aquesta not&iacute;cia,".
	 "llavors selecciona-la desde el dia Adjuntar Foto";

$TEXT019="Esborrar";
$TEXT020="Nom d'Arxiu";
$TEXT021="Id. Foto";
$TEXT022="Vista Pr&egrave;via";
$TEXT023="Guardar"; // See homesite-includes-dbwa.pnp before translate this
$TEXT024="Adjuntar Foto";
$TEXT025="Previsualitzar"; // See homesite-includes-dbwa.pnp before translate this
$TEXT026="Publicar";      // See homesite-includes-dbwa.pnp before translate this
$TEXT027="Data d'Enviament";
$TEXT028="Titular";

$TEXT029="La seg&uumls;ent es la llista de not&iacute;cies que estan pendents de la teva aprovaci&oacute;. ".
	 "Si pots veure aquesta llista, es que disposes dels privilegis suficients per fer-ho.<br>".
         "Pots esborrar directament una not&iacute;cia polsant a sobre la opci&oacute; Esborrar.<br>".
         "En cas contrari, polsa a sobre el t&iacute;tol de l'&agrave;lbum que vulguis editar i/o publicar.";

$TEXT030="Id.Info";
$TEXT031="Data";
$TEXT032="No hi han not&iacute;cies pendents de ser publicades.";
$TEXT033="Data d'Esborrament";

$TEXT034="La not&iacute;cia seleccionada ser&agrave; eliminada si continues.<br><br>".
         "Est&agrave;s; segur ?";

$TEXT035="Secci&oacute; buida !<br>".
         "Potser vulguis afegir alguna informaci&oacute; aqu&iacute;.<br>".
         "Si no, hauries d'esborrar aquesta secci&oacute;.";

$TEXT036="Comentar aquesta not&iacute;cia";

$TEXT037="Els comentaris s&oacute;n resposabilitat de qui els posi.".
	 "De cap manera ens fem responsables d'aquests comentaris. ";

$TEXT038="Respondre a aquest comentari";
$TEXT039="Resposta amb el t&iacute;tol";
$TEXT040="Est&as comentant aquestaesta not&iacute;cia";
$TEXT041="Est&as responent a aquesta not&iacute;cia";
$TEXT042="T&iacute;tol del comentari";
$TEXT043="Text del comentari";
$TEXT044="<br>No tens permisos suficients per publicar not&iacute;cias pendents!<br><br>".
         "Si vols ser editor, envia un email l'administrador del web.<br>&nbsp;";
$TEXT054="<br>No tens permisos suficients per editar not&iacute;cias d'altes usuaris!<br><br>".
         "Si vols ser editor, envia un email l'administrador del web.<br>&nbsp;";
$TEXT055="<br>No tens permisos suficients per esborrar not&iacute;cies !<br><br>".
         "Si vols ser editor, envia un email l'administrador del web.<br>&nbsp;";
$TEXT050="Llegir mes";
$TEXT051="paraules";
$TEXT052="$TITLE RSS 2.0 Feeds ";
$TEXT053="Subscriu-te als feeds de $TITLE. Actualment, estan disponibles els seg&uuml;ents canals de not&iacutecies:";


?>

==> homesitemaker-v0.4.4.tar.gz: homesitemaker/includes/languages/catalan/homesite-news.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004 Marcos Martinez Jimenez

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

//---------- ./homesite/info.php ----------

// Headline Row (HR)
$TEXT001="Enviar";
$TEXT002="Publicat el";
$TEXT003="per";
$TEXT004="Editat per &uacute;ltima vegada";

$TEXT005="Secci&oacute; vuida !<br>".
         "Potser vulguis afegir alguna informaci&oacute; aqu&iacute;.<br>".
         "Si no, hauries d&egrave;sborrar aquesta secci&oacute;.";

$TEXT006="Comentaris";
$TEXT007="Enviar comentari";
$TEXT008="Editar";
$TEXT009="Esborrar";
$TEXT010="Anterior";
$TEXT011="Seg&uulm;ent";
$TEXT012="Total";
$TEXT013="Data d'Edici&oacute;";
$TEXT014="Autor";
$TEXT015="Titular";
$TEXT048="Text Introductori";
$TEXT016="Text";
$TEXT049="Si est&agraves editant una not&iacute;cia molt llarga, quedar&agrave; millor si la divideixes en duess parts.<br>".
         "Utilitza el quadre d'edici&oacute; \"$TEXT048\" per introduir-la i el quadre \"$TEXT016\" per la resta.";
$TEXT017="Si env&iacute;es com HTML, llavors les etiquetes ser&agrave;n interpretades";
$TEXT045="Enviar com:";
$TEXT046="Text pla";
$TEXT047="HTML";

$TEXT018="Aquesta es la llista amb les fotos que hi ha actualment per a aquesta not&iacute;cia.<br>".
         "Pots seleccionar aquelles que vulguis esborrar<br>".
         "Si pel contrari vols afegir un altre imatge a aquesta not&iacute;cia,".
	 "llavors selecciona-la desde el dia Adjuntar Foto";

$TEXT019="Esborrar";
$TEXT020="Nom d'Arxiu";
$TEXT021="Id. Foto";
$TEXT022="Vista Pr&egrave;via";
$TEXT023="Guardar"; // See homesite-includes-dbwa.pnp before translate this
$TEXT024="Adjuntar Foto";
$TEXT025="Previsualitzar"; // See homesite-includes-dbwa.pnp before translate this
$TEXT026="Publicar";      // See homesite-includes-dbwa.pnp before translate this
$TEXT027="Data d'Enviament";
$TEXT028="Titular";

$TEXT029="La seg&uumls;ent es la llista de not&iacute;cies que estan pendents de la teva aprovaci&oacute;. ".
	 "Si pots veure aquesta llista, es que disposes dels privilegis suficients per fer-ho.<br>".
         "Pots esborrar directament una not&iacute;cia polsant a sobre la opci&oacute; Esborrar.<br>".
         "En cas contrari, polsa a sobre el t&iacute;tol de l&agrave;lbum que vulguis editar i/o publicar.";

$TEXT030="Id.Info";
$TEXT031="Data";
$TEXT032="No hi han not&iacute;cies pendents de ser publicades.";
$TEXT033="Data d$Egrave;sborrament";

$TEXT034="La not&iacute;cia seleccionada ser&agrave; eliminada si continues.<br><br>".
         "Est&agrave;s; segur ?";

$TEXT035="Secci&oacute; buida !<br>".
         "Potser vulguis afegir alguna informaci&oacute; aqu&iacute;.<br>".
         "Si no, hauries d&egrave;sborrar aquesta secci&oacute;.";

$TEXT036="Comentar aquesta not&iacute;cia";

$TEXT037="Els comentaris s&oacute;n resposabilitat de qui els posi.".
	 "De cap manera ens fem responsables d&agrave;aquests comentaris. ";

$TEXT038="Respondre a aquest comentari";
$TEXT039="Resposta amb el t&iacute;tol";
$TEXT040="Est&as comentant aquestaesta not&iacute;cia";
$TEXT041="Est&as responent a aquesta not&iacute;cia";
$TEXT042="T&iacute;tol del comentari";
$TEXT043="Text del comentari";
$TEXT044="<br>No tens permisos suficients per publicar not&iacute;cias pendents!<br><br>".
         "Si vols ser editor, envia un email l&agrave;dministrador del web.<br>&nbsp;";
$TEXT054="<br>No tens permisos suficients per editar not&iacute;cias d'altes usuaris!<br><br>".
         "Si vols ser editor, envia un email l&agrave;dministrador del web.<br>&nbsp;";
$TEXT055="<br>No tens permisos suficients per esborrar not&iacute;cies !<br><br>".
         "Si vols ser editor, envia un email l&agrave;dministrador del web.<br>&nbsp;";
$TEXT050="Llegir mes";
$TEXT051="paraules";
$TEXT052="$TITLE RSS 2.0 Feeds ";
$TEXT053="Subscriu-te als feeds de $TITLE. Actualment, estan disponibles els seg&uuml;ents canals de not&iacutecies:";
$TEXT054="Tots els feeds d&agrave;aquesta web han estat comprovats mitjan?ant";
?>
